@@ -1,5 +1,3 @@
-/* $Id: netlist.c,v 1.3 2005/02/28 08:15:59 bdejean Exp $ */
-
 /*
    This file is part of LibGTop 2.0.
 
@@ -31,7 +29,7 @@ static const unsigned long _glibtop_sysdeps_netlist = (1 << GLIBTOP_NETLIST_NUMB
 /* Init function. */
 
 void
-glibtop_init_netlist_s (glibtop *server)
+_glibtop_init_netlist_s (glibtop *server)
 {
 	server->sysdeps.netlist = _glibtop_sysdeps_netlist;
 }
